{% extends basetemplate|default:"base.html" %}

{% block content %}
  <div class="container-fluid">
    <div class="d-flex flex-row">
      <div>

        {% block col %}
        {% endblock col %}

      </div>

      {% block additionalcols %}
      {% endblock additionalcols %}

    </div>
  </div>
{% endblock content %}
